@@ -1,11 +1,10 @@
 /*****************************************************************************
- *  Written by Chris Dunlap <cdunlap@llnl.gov>.
- *  Copyright (C) 2007-2022 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2025 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2002-2007 The Regents of the University of California.
  *  UCRL-CODE-155910.
  *
  *  This file is part of the MUNGE Uid 'N' Gid Emporium (MUNGE).
- *  For details, see <https://dun.github.io/munge/>.
+ *  For details, see <https://github.com/dun/munge>.
  *
  *  MUNGE is free software: you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
@@ -101,9 +100,17 @@
  */
 #define MUNGE_MINIMUM_MD_LEN            16
 
-/*  Integer for the maximum size (in bytes) of a munge request message.
+/*  Integer for the maximum size (in bytes) of a munge credential payload.
  */
-#define MUNGE_MAXIMUM_REQ_LEN           1048576
+#define MUNGE_MAXIMUM_PAYLOAD_LEN       1048576
+
+/*  Integer for the maximum size (in bytes) of a munge request message.
+ *  An encode request may contain a payload, and a decode request will contain
+ *    a base64-encoded credential (~33% larger than the original payload).
+ *  Set the maximum request size to 2x the maximum payload size to account for
+ *    additional metadata and overhead.
+ */
+#define MUNGE_MAXIMUM_REQ_LEN           (MUNGE_MAXIMUM_PAYLOAD_LEN * 2)
 
 /*  Flag to denote whether group information comes from "/etc/group".
  *  If set, group information will not be updated unless this file
